[![CircleCI](https://circleci.com/gh/coderepocenter/ezrequest.svg?style=svg)](https://circleci.com/gh/coderepocenter/ezrequest)
[![codecov](https://codecov.io/gh/coderepocenter/ezrequest/branch/master/graph/badge.svg)](https://codecov.io/gh/coderepocenter/ezrequest)
[![Documentation Status](https://readthedocs.org/projects/ezrequest/badge/?version=latest)](https://ezrequest.readthedocs.io/en/latest/?badge=latest)

# ezrequest
ezrequest (Easy Request): A wrapper class around the famous request library, making certain use cases easier.

# Documentation
Click [here](https://ezrequest.readthedocs.io/en/latest/index.html) for the documentation or from a command prompt
switch to `docs` folder and issue:

```bash
make html
```

**NOTE:** prior to issuing `make html` you could issue:

```bash
conda install --file requirements.txt
```

to install the necessary requirements. Note that this is refering to the `requirements.txt` that exists in `docs` 
folder.
